summaryrefslogtreecommitdiffstats
path: root/webkit/fileapi/file_system_operation_interface.h
diff options
context:
space:
mode:
authormichaeln@google.com <michaeln@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-29 23:00:00 +0000
committermichaeln@google.com <michaeln@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2012-02-29 23:00:00 +0000
commita5230508efeea42e05005f43f9ffa140fbcc64c0 (patch)
tree89b4aedc784c9b0b1c93b757b35631e0fd06a884 /webkit/fileapi/file_system_operation_interface.h
parent55df9099f9350d906d7b03a4390687ac95269210 (diff)
downloadchromium_src-a5230508efeea42e05005f43f9ffa140fbcc64c0.zip
chromium_src-a5230508efeea42e05005f43f9ffa140fbcc64c0.tar.gz
chromium_src-a5230508efeea42e05005f43f9ffa140fbcc64c0.tar.bz2
Modify DeletableFileReference to not necessarily delete after all. Renamed the class to ShareableFileReference and fixed up the current callers with the new name and gypi files.
BUG=115603 Review URL: https://chromiumcodereview.appspot.com/9466025 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@124276 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/fileapi/file_system_operation_interface.h')
-rw-r--r--webkit/fileapi/file_system_operation_interface.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/webkit/fileapi/file_system_operation_interface.h b/webkit/fileapi/file_system_operation_interface.h
index 6777f34..163f402 100644
--- a/webkit/fileapi/file_system_operation_interface.h
+++ b/webkit/fileapi/file_system_operation_interface.h
@@ -8,7 +8,7 @@
#include "base/file_util_proxy.h"
#include "base/platform_file.h"
#include "base/process.h"
-#include "webkit/blob/deletable_file_reference.h"
+#include "webkit/blob/shareable_file_reference.h"
namespace base {
class Time;
@@ -20,7 +20,7 @@ class URLRequestContext;
} // namespace net
namespace webkit_blob {
-class DeletableFileReference;
+class ShareableFileReference;
}
class GURL;
@@ -90,22 +90,21 @@ class FileSystemOperationInterface {
// may want to download the file into a temporary snapshot file and then
// return the metadata of the temporary file.
//
// |deletable_file_ref| is used to manage the lifetime of the returned
// snapshot file. It can be set to let the chromium backend take
// care of the life time of the snapshot file. Otherwise (if the returned
- // file is not a temporary file to be deleted) the implementation can just
+ // file does not require any handling) the implementation can just
// return NULL. In a more complex case, the implementaiton can manage
// the lifetime of the snapshot file on its own (e.g. by its cache system)
// but also can be notified via the reference when the file becomes no
// longer necessary in the javascript world.
// Please see the comment for DeletableFileReference for details.
//
typedef base::Callback<void(
base::PlatformFileError result,
const base::PlatformFileInfo& file_info,
const FilePath& platform_path,
- const scoped_refptr<webkit_blob::DeletableFileReference>&
- deletable_file_ref
+ const scoped_refptr<webkit_blob::ShareableFileReference>& file_ref
)> SnapshotFileCallback;
// Used for Write().
@@ -90,22 +90,21 @@ class FileSystemOperationInterface {
// return the metadata of the temporary file.
//
- // |deletable_file_ref| is used to manage the lifetime of the returned
+ // |file_ref| is used to manage the lifetime of the returned
// snapshot file. It can be set to let the chromium backend take
// care of the life time of the snapshot file. Otherwise (if the returned
@@ -90,22 +90,21 @@ class FileSystemOperationInterface {
// but also can be notified via the reference when the file becomes no
// longer necessary in the javascript world.
- // Please see the comment for DeletableFileReference for details.
+ // Please see the comment for ShareableFileReference for details.
//
typedef base::Callback<void(